# ==============================================================================
# FILE: 3_Source_Code/decyphr/analysis_plugins/__init__.py
# ==============================================================================
# PURPOSE: This file makes the 'analysis_plugins' directory a Python package.

# This is a critical step that allows Python to treat all the 'pXX_...'
# subdirectories as modules that can be imported from other parts of the
# decyphr library, such as the main_orchestrator.

# This file can remain empty.