# ==============================================================================
# FILE: 3_Source_Code/decyphr/analysis_plugins/p04_advanced_outliers/__init__.py
# ==============================================================================
# PURPOSE: This file makes the 'p04_advanced_outliers' directory a Python package.

# Its presence is essential for the Python interpreter to allow imports
# from this directory, such as:
# from .analysis_plugins.p04_advanced_outliers import run_analysis

# This file can remain empty.